@@ -84,4 +84,7 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    try:
+        main()
+    except Exception as err:
+        sys.stderr.write("auto_schema error: "+str(err))
